/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: StopEngineCommand.as 4798 2009-08-07 12:30:47Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.rules.enginedashboard.command
{
import com.adobe.cairngorm.commands.ICommand;
import com.adobe.cairngorm.control.CairngormEvent;
import com.adobe.cairngorm.control.CairngormEventDispatcher;

import flash.utils.getQualifiedClassName;

import mx.rpc.IResponder;
import mx.rpc.events.FaultEvent;

import org.ow2.jasmine.kerneos.common.event.KerneosNotificationEvent;
import org.ow2.jasmine.monitoring.eos.common.controls.ServerSideException;
import org.ow2.jasmine.monitoring.eos.common.events.ServerSideExceptionEvent;
import org.ow2.jasmine.monitoring.eos.rules.enginedashboard.business.IStopEngineDelegate;
import org.ow2.jasmine.monitoring.eos.rules.enginedashboard.event.EngineDashboardEvent;
import org.ow2.jasmine.monitoring.eos.rules.enginedashboard.model.EngineDashboardModelLocator;
import org.ow2.jasmine.monitoring.eos.rules.enginedashboard.model.domain.EngineDashboardModel;

/**
* Stop the rule engine
* 
* @author Julien Nicoulaud
*/
public class StopEngineCommand implements ICommand, IResponder
{

    // =========================================================================
    // Execution
    // =========================================================================
    
    /**
    * Send the event to the java side, using the business layer of the pattern
    */
    public function execute(event:CairngormEvent):void
    {
        // Retrieve the command delegate
        var delegate:IStopEngineDelegate = 
        	EngineDashboardModelLocator.getInstance().getStopEngineDelegate();
        
        // Set this object as a responder
        delegate.responder = this;
        
        // Retrieve the component model
        var model:EngineDashboardModel = 
        	EngineDashboardModelLocator.getInstance().engineDashboardModel;
        
        // Dispatch a notification to Kerneos
        CairngormEventDispatcher.getInstance().dispatchEvent(
            new KerneosNotificationEvent(KerneosNotificationEvent.KERNEOS_NOTIFICATION + model.componentID,
                                         (getQualifiedClassName(this).split("::"))[1] + ": Stopping the rule engine instance \"" +
                                         model.ruleEngineName + "\"",
                                         KerneosNotificationEvent.DEBUG)
        );
                
        // Execute a server-side method thanks to the delegate
        delegate.stopEngine(model.ruleEngineName);
    }


    // =========================================================================
    // Result handling
    // =========================================================================

    /**
    * Get the result of the java side. this method is called on each event
    * returned from the Java side.
    */
    public function result(event : Object):void
    {
        /*
        * Example: Store the result in the model.
        *
        * // Locate the model
        * var model:EngineDashboardModelLocator =
        * 	EngineDashboardModelLocator.getInstance();
        *
        * // Store the message in some model property
        * model.something = (event as ResultEvent).result as String;
        */
        
        // Do nothing
        
    }


    // =========================================================================
    // Fault handling
    // =========================================================================
    
    /**
    * Handle fault messages
    */
    public function fault(event : Object) : void
    {
        // Retrieve the fault event
        var faultEvent : FaultEvent = FaultEvent(event);
        
        // Retrieve the component model
        var model:EngineDashboardModel = 
            EngineDashboardModelLocator.getInstance().engineDashboardModel;
        
        // Tell the view and let it handle this
        var serverSideExceptionEvent : ServerSideExceptionEvent =
            new ServerSideExceptionEvent(
                ServerSideExceptionEvent.SERVER_SIDE_EXCEPTION + model.componentID,
                new ServerSideException("Error while stopping the rule engine",
                                        "The operation could not be performed."
                                        + "\n" + faultEvent.fault.faultCode
                                        + "\n" + faultEvent.fault.faultString,
                                        faultEvent.fault.getStackTrace()));
        CairngormEventDispatcher.getInstance().dispatchEvent(serverSideExceptionEvent);
        
        // Update the status
        CairngormEventDispatcher.getInstance().dispatchEvent(
            new EngineDashboardEvent(EngineDashboardEvent.UPDATE_ENGINE_STATUS)
        );
    }

}
}
