/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:RulesManagerModelLocator.as 2485 2008-09-30 14:14:35Z nicoulaj $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.rules.enginedashboard.model
{

import com.adobe.cairngorm.model.ModelLocator;

import org.ow2.jasmine.monitoring.eos.rules.enginedashboard.business.*;
import org.ow2.jasmine.monitoring.eos.rules.enginedashboard.model.domain.*;
import org.ow2.jasmine.monitoring.eos.rules.enginedashboard.model.presentation.*;
	
/**
* Cairngorm Model Locator for the rule engine dashboard.
* 
* @author Julien Nicoulaud
*/
[Bindable]
public class EngineDashboardModelLocator implements ModelLocator 
{
    // =========================================================================
    // Variables
    // =========================================================================
            
    /**
    * Singleton instance of this locator
    */
	private static var instance:EngineDashboardModelLocator;
	
	
    // Models
    
    /**
    * Rule engine dashboard domain model
    */
    public var engineDashboardModel:EngineDashboardModel;
    
    /**
    * Rule engine dashboard presentation model
    */
    public var engineDashboardPresentationModel:EngineDashboardPM;
    

    // Command delegates unique instances
    
    /**
    * UpdateEngineStatus delegate unique instance
    */
    private var updateEngineStatusDelegate:IUpdateEngineStatusDelegate = null;
	
    /**
    * StartEngine delegate unique instance
    */
    private var startEngineDelegate:IStartEngineDelegate = null;
    
    /**
    * StopEngine delegate unique instance
    */
    private var stopEngineDelegate:IStopEngineDelegate = null;


    // =========================================================================
    // Construction and singleton instance access
    // =========================================================================
    
    /**
    * Constructor
    */
	public function EngineDashboardModelLocator()
	{
		// Instanciate the singleton
		if(instance!=null) {
			throw new Error("Error: Singletons can only be" + 
							"instantiated via getInstance() method!");
		}
		EngineDashboardModelLocator.instance = this;
	}
	
	/**
	* EngineDashboardModelLocator singleton instance getter
	*/
	public static function getInstance():EngineDashboardModelLocator
	{
		if(instance==null){
            
            // Instanciate the ModelLocator
            instance = new EngineDashboardModelLocator();
            
            // Instanciate the models
            instance.engineDashboardModel = new EngineDashboardModel();
            instance.engineDashboardPresentationModel = new EngineDashboardPM(instance.engineDashboardModel);
            
        }
		return instance;
	}
	
	
    // =========================================================================
    // Delegates getters
    // =========================================================================
    
    /**
    * "Update engine status command" delegate getter
    */
    public function getUpdateEngineStatusDelegate():IUpdateEngineStatusDelegate {
        if (this.updateEngineStatusDelegate == null) {
            this.updateEngineStatusDelegate = new UpdateEngineStatusDelegate();
        }
        return this.updateEngineStatusDelegate;
    }
    
    /**
    * "Start engine command" delegate getter
    */
    public function getStartEngineDelegate():IStartEngineDelegate {
        if (this.startEngineDelegate == null) {
            this.startEngineDelegate = new StartEngineDelegate();
        }
        return this.startEngineDelegate;
    }
            
    /**
    * "Stop engine command" delegate getter
    */
    public function getStopEngineDelegate():IStopEngineDelegate {
        if (this.stopEngineDelegate == null) {
            this.stopEngineDelegate = new StopEngineDelegate();
        }
        return this.stopEngineDelegate;
    }
}
}